/*******************************************************************************
 * Copyright (c) 2003, 2005 IBM Corporation and others. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: IBM Corporation - initial API and implementation
 ******************************************************************************/
package org.eclipse.stp.core.infrastructure.assertion;

/**
 * <code>AssertionFailedException</code> is a runtime exception thrown by some
 * of the methods in <code>Assert</code>.
 * <p>
 * This class is not declared public to prevent some misuses; programs that
 * catch or otherwise depend on assertion failures are susceptible to unexpected
 * breakage when assertions in the code are added or removed.
 * </p>
 */
public class AssertionFailedException extends RuntimeException {
   /**
    * All serializable objects should have a stable serialVersionUID
    */
   private static final long serialVersionUID = 1L;

   private Throwable         wrappedException;

   /**
    * Constructs a new exception with the given message.
    */
   public AssertionFailedException(String detail) {
      super(detail);
   }

   /**
    * Constructs a new exception with the given message.
    */
   public AssertionFailedException(Throwable t) {
      super(t.getMessage());
      wrappedException = t;
   }

   public final Throwable getWrappedException() {
      return wrappedException;
   }
}
